-- This channel is a simple example channel receiving HL7 ADT messages,
-- performing minor processing on the message before writing each message
-- to a defined file in the Iguana working directory. 

-- Local Modules 
local map = require 'mappings'
local filters = require 'filters'


function main(Data)
   
   --(1) PARSING
   local OrigMsg, MsgType, err = hl7.parse{vmd='hl7.vmd',data=Data}
     
   --(2) FILTERING & ALERTING
   if filters.type(MsgType) == false or filters.endpt(OrigMsg.MSH) == false then 
      return nil
   end 
   
   --(3) BUILDING OUTBOUND MESSAGE STRUCTURE
   local Out = hl7.message{vmd='hl7.vmd', name=MsgType}

   --(4) MAPPING
   -- Map entire message and alter segments  
   Out:mapTree(OrigMsg)
   map.AlterMSH(Out.MSH) 
   map.AlterPID(Out.PID)

   --(5) SEND TO DESTINATION
   -- drop messages in Iguana working directory 
   local destination = iguana.workingDir()
   local filename = 'testFile'..'.txt'

   -- open file in append mode
   local file = io.open(destination..filename, 'a')
   -- write message to file
   file:write(Out:S())
   file:close()
	
   -- add informational log to state successful processing
   iguana.logInfo('Message was processed and written to local directory')
end
